import { ReactNode, useState, useMemo } from 'react';
import { Space, Statistic, Flex } from 'antd';
import type { StatisticProps } from 'antd';
import CountUp from 'react-countup';
import styles from './index.less'
import upIcon from '@/assets/images/urbanSituation/up.png'
import bottom from '@/assets/images/urbanSituation/bottom.png'
import Modal from '@/components/HncyModal';
import ImportantEvents from '@/pages/Common/Event/ImportantEvents';
import CommonList from '@/pages/Common/Event/CommonList';
import GeneralSituation from '@/pages/Common/Event/GeneralSituation';
import ToDisposed from '@/pages/Common/Event/ToDisposed';
import AnalysisCompletionRate from '@/pages/Common/Event/AnalysisCompletionRate';
import DifficultEvents from '@/pages/Common/Event/DifficultEvents';


const formatter: StatisticProps['formatter'] = (value) => (
  <CountUp end={value as number} separator="" />
);

const Problem = () => {

  const [modalOpt, setModalOpt] = useState<{
    open: boolean;
    title: string;
    type: string; // 弹窗类型：todayNum 今日事件数，disposalNum 待处理事件数
    width?: number;
    height?: number
  }>({
    open: false,
    title: '',
    type: ''
  })

  // 渲染弹窗内容
  const renderModal: ReactNode = useMemo(() => {
    let comp: any = {
      '1': <ImportantEvents />,
      '2': <CommonList />,
      '3': <GeneralSituation />,
      '4': <ToDisposed />,
      '5': <AnalysisCompletionRate />,
      '6': <DifficultEvents /> 
    };
    return comp[modalOpt?.type] || <></>;
  }, [modalOpt]);


  const topCard = [
    {
      name: '重要事件',
      value: 1208,
      modalConf: {
        type: '1',
        title: '事件已推送至重要事件（城管24高速通道高效处置）',
      },
    },
    {
      name: '多跨事件',
      value: 1208,
      modalConf: {
        type: '2',
        title: '事件已推送至多跨事件（市城运平台协调处置）',
      },
    },
    {
      name: '应急事件',
      value: 1208,
      modalConf: {
        type: '2',
        title: '事件已推送至应急事件（综合指挥调度应急处置）'
      },
    },
    {
      name: '其它',
      value: 1208,
      modalConf: {
        type: '2',
        title: '常规处置事件'
      },
    }
  ]

  const bottomCard = [
    {
      name: '市民投诉',
      value: 1208,
      modalConf: {
        type: '2',
        title: '市民投诉事件'
      },
    },
    {
      name: '物联感知',
      value: 1208,
      modalConf: {
        type: '2',
        title: '物联感知事件'
      },
    },
    {
      name: '人工巡查',
      value: 1208,
      modalConf: {
        type: '2',
        title: '人工巡查事件'
      },
    },
    {
      name: '其它',
      value: 0,
      modalConf: {
        type: '2',
        title: '其它渠道上报事件'
      },
    }
  ]

  const centerStatistic = [
    {
      name: '待处置',
      value: 25,
      unit: '件',
      modalConf: {
        type: '4',
        title: '待处置事件'
      },
    },
    {
      name: '办结率',
      value: 75,
      unit: '%',
      modalConf: {
        type: '5',
        title: '办结率分析',
        width: 1228,
        height: 846
      },
    },
    {
      name: '委内疑难案件',
      value: 125,
      unit: '件',
      modalConf: {
        type: '6',
        title: '疑难案件'
      },
    },
    {
      name: '委外疑难案件',
      value: 125,
      unit: '件',
      modalConf: {
        type: '6',
        title: '疑难案件'
      },
    }
  ]

  return (
    <div className={styles.wrap}>
      <div className={styles.header}>
        <span className={styles.title}>城市问题</span>
      </div>
      <div className={styles.content}>
        <Flex gap={37}>
          {
            topCard.map((item) => (
              <div className={styles.card} key={item.name}>
                <div className={styles.numCard} onClick={() => setModalOpt({ open: true, ...item.modalConf })}>
                  <Space>
                    <Statistic value={item.value} formatter={formatter} />
                    <span>件</span>
                  </Space>
                  <div className={styles.name}>{item.name}</div>
                </div>
                <img src={upIcon} alt="" />
              </div>
            ))
          }
        </Flex>
        <div className={styles.center}>
          <Space
            style={{ cursor: 'pointer' }}
            onClick={() => setModalOpt({
              open: true,
              type: '3',
              title: '事件总体情况',
            })}
          >
            <span>事件总量</span>
            <Statistic value={450000} formatter={formatter} />
            <span>件</span>
          </Space>
          <Flex justify='space-around'>
            {
              centerStatistic.map((item) => (
                <div key={item.name} style={{ cursor: 'pointer' }} onClick={() => setModalOpt({ open: true, ...item.modalConf })}>
                  <Space>
                    <Statistic value={item.value} />
                    <span className={styles.unit}>{item.unit}</span>
                  </Space>
                  <div>{item.name}</div>
                </div>
              ))
            }
          </Flex>
        </div>
        <div style={{ textAlign: 'center' }}>
          <img src={bottom} alt="" />
        </div>
        <Flex gap={37}>
          {
            bottomCard.map((item) => (
              <div className={styles.card} key={item.name}>
                <div className={styles.numCard} onClick={() => setModalOpt({ open: true, ...item.modalConf })}>
                  <Space>
                    <Statistic value={item.value} formatter={formatter} />
                    <span>件</span>
                  </Space>
                  <div className={styles.name}>{item.name}</div>
                </div>
              </div>
            ))
          }
        </Flex>
      </div>

      <Modal
        open={modalOpt?.open}
        title={modalOpt?.title}
        onCancel={() => setModalOpt({ open: false, title: '', type: '' })}
        width={modalOpt?.width ?? 1772}
        height={modalOpt?.height ?? 846}
        mask={false}
      >
        {renderModal}
      </Modal>
    </div>
  )
}

export default Problem